# crjbsim
Light-weight Python simulation utilities, including a discrete event scheduling framework.

Similar to https://github.com/ocadotechnology/Ocava (Ocado's Java simulation utilities, which I also wrote a lot of), but for Python.

**Brought to you by Green Vertex Consulting:** Here to help with your simulation needs. Visit https://www.greenvertex.dev/simulation-digital-twin to find out more, and get in touch to learn what we can do for you.
